!
! >>> FIBDEF.INC <<<
!
! Imp equivalent of the $FIBDEF macro
!
! $EQU FIB$M_NOWRITE 1
! $EQU FIB$M_DLOCK 2
! $EQU FIB$M_BLK_LOCK 4
! $EQU FIB$M_SPOOL 16
! $EQU FIB$M_WRITECK 32
! $EQU FIB$M_SEQONLY 64
! $EQU FIB$M_WRITE 256
! $EQU FIB$M_READCK <^X200>
! $EQU FIB$M_NOREAD <^X400>
! $EQU FIB$M_NOTRUNC <^X800>
! $EQU FIB$M_EXECUTE <^X10000>
! $EQU FIB$M_PRSRV_ATR <^X20000>
! $EQU FIB$M_RMSLOCK <^X40000>
! $EQU FIB$M_WRITETHRU <^X80000>
! $EQU FIB$M_NOLOCK <^X100000>
! $EQU FIB$M_NORECORD <^X200000>
! $EQU FIB$M_REWIND 8
! $EQU FIB$M_CURPOS 16
! $EQU FIB$M_UPDATE 64
!

%record %format Fid Fm ( %short Num, Seq, %byte Rvn, Nmx )

%record %format Fib Fm ( (%integer Acctl %or %byte Unu1, Unu2, Unu3, Wsize),
                          %record(Fid Fm) Fid,
                         (%record(Fid Fm) Did %or %integer Accdata),
                          %integer WCC,
                          %short Nmctl,
                         (%short Ctrlfunc  %or %short   Exctl),
                         (%integer Ctrlval %or %integer Exsz),
                                               %integer Exvbn,
                          %byte Alopts, Alalign,
                          %string(9) Alloc {10 bytes of junk},
                          %short Verlimit, Not Used )

!
! _WCC bits
!
! $EQU FIB$M_ALLVER 8
! $EQU FIB$M_ALLTYP 16
! $EQU FIB$M_ALLNAM 32
! $EQU FIB$M_WILD 256
! $EQU FIB$M_NEWVER <^X200>
! $EQU FIB$M_SUPERSEDE <^X400>
! $EQU FIB$M_FINDFID <^X800>
! $EQU FIB$M_LOWVER <^X4000>
! $EQU FIB$M_HIGHVER <^X8000>
!
! _NMCTL bits
!
! $EQU FIB$M_ALCON 1
! $EQU FIB$M_ALCONB 2
! $EQU FIB$M_FILCON 4
! $EQU FIB$M_ALDEF 8
! $EQU FIB$M_ALLOCATR 16
! $EQU FIB$M_EXTEND 128
! $EQU FIB$M_TRUNC 256
! $EQU FIB$M_NOHDREXT <^X200>
! $EQU FIB$M_MARKBAD <^X400>
! $EQU FIB$M_NOCHARGE <^X8000>

! $EQU FIB$M_EXACT 1
! $EQU FIB$M_ONCYL 2
! $DEF FIB$B_ALOPTS .BLKB
!
! _ALOPTS values
!
! $EQU FIB$C_CYL 1
! $EQU FIB$C_LBN 2
! $EQU FIB$C_VBN 3
! $EQU FIB$C_RFI 4
!! $DEF FIB$B_ALALIGN .BLKB
!! $EQU FIB$S_ALLOC 10
!! $DEF FIB$W_ALLOC
!! $EQU FIB$S_LOC_FID 6
!! $DEF FIB$W_LOC_FID
!! $DEF FIB$W_LOC_NUM .BLKW
!! $DEF FIB$W_LOC_SEQ .BLKW
!! $DEF FIB$W_LOC_RVN
!! $DEF FIB$B_LOC_RVN .BLKB
!! $DEF FIB$B_LOC_NMX .BLKB
!! $DEF FIB$L_LOC_ADDR .BLKL

!! $EQU FIB$C_REWINDVOL 1
!! $EQU FIB$C_POSEND 2
!! $EQU FIB$C_NEXTVOL 3
!! $EQU FIB$C_SPACE 4
!! $EQU FIB$C_ILLEGAL 5
!! $EQU FIB$C_REWINDFIL 6
!! $EQU FIB$C_LOCK_VOL 7
!! $EQU FIB$C_UNLK_VOL 8
!! $EQU FIB$C_ENA_QUOTA 9
!! $EQU FIB$C_DSA_QUOTA 10
!! $EQU FIB$C_ADD_QUOTA 11
!! $EQU FIB$C_EXA_QUOTA 12
!! $EQU FIB$C_MOD_QUOTA 13
!! $EQU FIB$C_REM_QUOTA 14
!! $EQU FIB$C_USEREOT 15
!! $EQU FIB$C_REMAP 16
!! $EQU FIB$M_ALL_MEM 1
!! $EQU FIB$M_ALL_GRP 2
!! $EQU FIB$M_MOD_USE 4
!! $EQU FIB$M_MOD_PERM 8
!! $EQU FIB$M_MOD_OVER 16

%end %of %file
