!
! IMP Equivalent of $DEVDEF macro.
!
%const %integer DEV M REC      = 16_00000001, {device is record oriented}
                DEV M CCL      = 16_00000002, {carriage control}
                DEV M TRM      = 16_00000004, {terminal device}
                DEV M DIR      = 16_00000008,
                DEV M SDI      = 16_00000010,
                DEV M SQD      = 16_00000020, {device is sequential access}
                DEV M SPL      = 16_00000040, {spooled device}
                DEV M NET      = 16_00002000,
                DEV M FOD      = 16_00004000, {file oriented device}
                DEV M SHR      = 16_00010000, {device shareable}
                DEV M GEN      = 16_00020000,
                DEV M AVL      = 16_00040000, {device online and available}
                DEV M MNT      = 16_00080000, {volume mounted}
                DEV M MBX      = 16_00100000, {mailbox device}
                DEV M DMT      = 16_00200000,
                DEV M ELG      = 16_00400000,
                DEV M ALL      = 16_00800000,
                DEV M FOR      = 16_01000000, {foreign device}
                DEV M SWL      = 16_02000000,
                DEV M IDV      = 16_04000000, {device capable of input}
                DEV M ODV      = 16_08000000, {device capable of output}
                DEV M RND      = 16_10000000, {device capable of random access}
                DEV M RTM      = 16_20000000, {real-time device}
                DEV M RCK      = 16_40000000, {perform data check all reads}
                DEV M WCK      = 16_80000000  {perform data check all writes}

%end %of %file
