%endoflist;  !PAM interface
%externalstring(255)%fnspec CLIPARAM
%recordformat paminfo(%byte GROUPSEP,KEYFLAG, %short allflags,
                      %record(*)%name params)
%external%record(paminfo)%mapspec PAM
%constinteger PAM NEWGROUP=1, PAM NODEFAULT=2, PAM MAJOR=4, PAM KEEPCASE=8,
              PAM INFILE=16, PAM OUTFILE=32
%external%routinespec DEFINE PARAM %alias "PAM_DEFSTRING" %c
          (%string(255) text, %string(*)%name variable, %integer flags)
%external%routinespec DEFINE INT PARAM %alias "PAM_DEFINT" %c
          (%string(255) text, %integername variable, %integer flags)
%external%routinespec DEFINE ENUM PARAM %alias "PAM_DEFENUM" %c
          (%string(255) text, %bytename variable, %integer flags)
%external%routinespec DEFINE BOOLEAN PARAMS %alias "PAM_DEFBOOL" %c
          (%string(255) text, %integername variable, %integer flags)
%external%routinespec PROCESS PARAMETERS %alias "PAM_PROCESS"(%string(255) parm)
%list;%endoffile
