! facility base conditions

%const %integer FAC BAS      = 26 << 16 {BASIC support}
%const %integer FAC BLI      = 20 << 16 {BLISS transportable support}
%const %integer FAC B32      = 27 << 16 {BLISS-32 support}
%const %integer FAC COB      = 25 << 16 {COBOL support}
%const %integer FAC FOR      = 24 << 16 {FORTRAN support}
%const %integer FAC LIB      = 21 << 16 {general utility}
%const %integer FAC MTH      = 22 << 16 {Math}
%const %integer FAC OTS      = 23 << 16 {language independent}
%const %integer FAC PAS      = 33 << 16 {PASCAL support}
%const %integer FAC RMS      =  1 << 16 {RMS internals and status codes}
%const %integer FAC SORT     = 28 << 16 {VAX-11 SORT}
%const %integer FAC SS       =  0 << 16 {system service status codes}
%const %integer FAC STR      = 36 << 16 {string}
%const %integer FAC XPO      = 32 << 16 {BLISS transportable}

%end %of %file
