!
! Heap management utilities in the IMP library.
!
! Note that NEW and DISPOSE are not included here because
! they appear in the standard predef file.
!
%external %integer %function %spec Get Space %alias "IMP_GET_SPACE" -
                                                ( %integer Bytes )

%external %routine %spec Free Space %alias "IMP_FREE_SPACE" -
                                  ( %integer Bytes, Where )

%external %string(*) %map %spec Heap String %alias "IMP_HEAP_STRING" -
                                          ( %string(255) S )

%end %of %file
