%const %integer %c
   MTH WRONUMARG = 16_00168284,
   MTH INVARGMAT = 16_0016828C,
   MTH UNDEXP    = 16_00168294,
   MTH LOGZERNEG = 16_0016829C,
   MTH SQUROONEG = 16_001682A4,
   MTH SIGLOSMAT = 16_001682BC,
   MTH FLOOVEMAT = 16_001682C4,
   MTH FLOUNDMAT = 16_001682CC,
   MTH SINCOSSIG = 16_001682BC
