!
! IMP equivalent of $DIBDEF macro
!
%record %format Dib Fm ( %integer Devchar,    {device characteristics}
                         %byte Devclass, Devtype,
                         %short Devbufsiz,
                         ( %integer Devdepend %or
                           %byte Sectors, Tracks, %short Cylinders ),
                         %short Unit, Devnamoff,
                         %integer Pid, Ownuic,
                         %short Vprot, Errcnt,
                         %integer Opcnt,
                         %short Volnamoff, Recsiz,
                         %string(75) Devname,
                         %integer Maxblock )
%end %of %file
