!
! >> IMP Equivalent of $MSGDEF macro <<
!
! Symbolic names for system mailbox messages.
!
%const %integer %c
   MSG TRMUNSOLIC = 16_00000001, {unsolicited terminal data}
   MSG CRUNSOLIC  = 16_00000002, {unsolicited card reader data}
   MSG DELPROC    = 16_00000003, {delete process}
   MSG SNDSMB     = 16_00000004, {send to symbiont manager}
   MSG DEVOFFLIN  = 16_00000005, {device offline}
   MSG TRMHANGUP  = 16_00000006, {terminal hangup}
   MSG DEVONLIN   = 16_00000007, {device online}
   MSG SMBINI     = 16_00000008, {symbiont is initiated}
   MSG OPRQST     = 16_00000008, {operator request}
   MSG SMBDON     = 16_00000009, {symbiont has finished}
   MSG OPREPLY    = 16_00000009, {operator reply}
   MSG SNDACC     = 16_0000000A, {send to accounting manager}
   MSG XM DATAVL  = 16_0000000B, {data available (DMC-11)}
   MSG XM SHUTDN  = 16_0000000C, {unit shutdown  (DMC-11)}
   MSG XM ATTN    = 16_0000000D, {unit attention (DMC-11)}
   MSG INIOPR     = 16_00000010, {initiate file printing}
   MSG ABOOPR     = 16_00000011, {abort printing a file}
   MSG SUSOPR     = 16_00000012, {pause printing a file}
   MSG RESOPR     = 16_00000013, {resume printing a file}
   MSG DELSMB     = 16_00000014, {symbiont should delete itself}
   MSG SMBRSP     = 16_00000020, {symbiont response}
   MSG ACCRSP     = 16_00000021, {accounting manager response}
   MSG SCANBAD    = 16_00000028, {???}
   MSG SCANRSP    = 16_00000029, {???}
   MSG ABORT      = 16_00000030, {network partner aborted link}
   MSG CONFIRM    = 16_00000031, {network connect confirm}
   MSG CONNECT    = 16_00000032, {network inbound connect initiate}
   MSG DISCON     = 16_00000033, {network partner disconnected-hangup}
   MSG EXIT       = 16_00000034, {network partner exited prematurely}
   MSG INTMSG     = 16_00000035, {network interrupt message; unsolicited data}
   MSG PATHLOST   = 16_00000036, {network path lost to partner}
   MSG PROTOCOL   = 16_00000037, {network protocol error}
   MSG REJECT     = 16_00000038, {network connect reject}
   MSG THIRDPARTY = 16_00000039, {network third party disconnect}
   MSG TIMEOUT    = 16_0000003A, {network connect timeout}
   MSG NETSHUT    = 16_0000003B, {???}
   MSG NODEACC    = 16_0000003C  {???}

%end %of %file
