!
! IMP description of VAX call frames
!
! Equivalent of $SFDEF macro
!
%record %format Frame Fm ( %integer Handler,
                           %short Save PSW, Save Mask,
                           %integer Save AP, Save FP, Save PC )

!
! Now the same stuff again in case you are an in-line
! assembly language man...
!
%const %integer SF A HANDLER    = 0

%const %integer SF W SAVE PSW   = 4,
                SF M C    = 2_0000 0001,
                SF M V    = 2_0000 0010,
                SF M Z    = 2_0000 0100,
                SF M N    = 2_0000 1000,
                SF M TBIT = 2_0001 0000,
                SF M IV   = 2_0010 0000,
                SF M FU   = 2_0100 0000,
                SF M DV   = 2_1000 0000

%const %integer SF W SAVE MASK  = 6,
                SF V SAVE MASK  = 0,
                SF S SAVE MASK  = 12,
                SF M CALLS      = 1<<13,
                SF V STACKOFFS  = 14,
                SF S STACKOFFS  = 2

%const %integer SF L SAVE AP    = 8,
                SF L SAVE FP    = 12,
                SF L SAVE PC    = 16,
                SF L SAVE REGS  = 20
