!
! IMP Equivalent of the $HLPDEF macro
!

!
! Flags passed to the procedure passed to LBR$GET_HELP
!
%const %integer HLP M NOHLPTXT  = 1,       {specified help cannot be found}
                HLP M KEYNAMLIN = 2,       {text contains key names of text}
                HLP M OTHERINFO = 4        {part of addition help available}

!
! Flag values for LBR$OUTPUT_HELP
!
%const %integer HLP M PROMPT    = 1 << 0,  {/PROMPT}
                HLP M PROCESS   = 1 << 1,  {/USERLIBRARY=PROCESS}
                HLP M GROUP     = 1 << 2,  {/USERLIBRARY=GROUP}
                HLP M SYSTEM    = 1 << 3,  {/USERLIBRARY=SYSTEM}
                HLP M LIBLIST   = 1 << 4,  {list libraries available too}
                HLP M HELP      = 1 << 5,  {add the HELP text as well}
                HLP M SPARE1    = 1 << 6,
                HLP M SPARE2    = 1 << 7,
                HLP M PAGE      = 1 << 8,
                HLP M OUTPUT    = 1 << 9,
                HLP M LIBRARY   = 1 << 10,
                HLP M ALL       = 1 << 11,
                HLP M PAGEDEF   = 1 << 12,
                HLP M PMPTDEF   = 1 << 13,
                HLP M NOTTERM   = 1 << 14

%end %of %file
