                                            {April 27, 1982  12:00 AM}
%const %integer OPC NM CENTRL = 1<<(0+8)
%const %integer OPC NM PRINT  = 1<<(1+8)
%const %integer OPC NM TAPES  = 1<<(2+8)
%const %integer OPC NM DISKS  = 1<<(3+8)
%const %integer OPC NM DEVICE = 1<<(4+8)
%const %integer OPC NM CARDS  = 1<<(5+8)
%const %integer OPC NM NTWORK = 1<<(6+8)
%const %integer OPC NM OPER1  = 1<<(12+8)
%const %integer OPC NM OPER2  = 1<<(13+8)
%const %integer OPC NM OPER3  = 1<<(14+8)
%const %integer OPC NM OPER4  = 1<<(15+8)
%const %integer OPC NM OPER5  = 1<<(16+8)
%const %integer OPC NM OPER6  = 1<<(17+8)
%const %integer OPC NM OPER7  = 1<<(18+8)
%const %integer OPC NM OPER8  = 1<<(19+8)
%const %integer OPC NM OPER9  = 1<<(20+8)
%const %integer OPC NM OPER10 = 1<<(21+8)
%const %integer OPC NM OPER11 = 1<<(22+8)
%const %integer OPC NM OPER12 = 1<<(23+8)
%const %integer OPC NM ALL    = 1<<(24+8)-1
%const %integer OPC NM NONE   = 0

%external %routine %spec Op Enable ( %integer Enab, Mask, %string(15) Device )
%external %routine %spec Op Status (                      %string(15) Device )

%end %of %file
