%record %format Getmsg Fm ( %byte Reserved, FAO Count,
                            %byte User Value, Reserved2 )

%external %integer %function %spec GETMSG %alias "IMP_GETMSG" ( -
          %integer Msgid, %string(*) %name Resultant,
          %integer Flags, %record(Getmsg Fm) %name Outadr )

%external %string(255) %function %spec GET MESSAGE %alias -
          "IMP_GET_MESSAGE" ( %integer Msgid )
