%const %integer RMS SUC       = 16_10001
%const %integer RMS NORMAL    = 16_10001
%const %integer RMS CONTROLO  = 16_10609
%const %integer RMS CREATED   = 16_10619
%const %integer RMS CONTROLY  = 16_10611
%const %integer RMS SUPERSEDE = 16_10631
%const %integer RMS CONTROLC  = 16_10651
%const %integer RMS STALL     = 16_18001
%const %integer RMS PENDING   = 16_18009
%const %integer RMS OK DUP    = 16_18011
%const %integer RMS OK IDX    = 16_18019
%const %integer RMS TEMP10    = 16_18029
%const %integer RMS OK RLK    = 16_18021
%const %integer RMS OK ALK    = 16_18039
%const %integer RMS KFF       = 16_18031
%const %integer RMS OK RNF    = 16_18049
%const %integer RMS OK DEL    = 16_18041
%const %integer RMS OK NOP    = 16_18059
%const %integer RMS OK LIM    = 16_18051
%const %integer RMS BOF       = 16_18198
%const %integer RMS RTB       = 16_181A8
%const %integer RMS RNL       = 16_181A0
%const %integer RMS TNS       = 16_181B8
%const %integer RMS TMO       = 16_181B0
%const %integer RMS PES       = 16_181C8
%const %integer RMS BES       = 16_181C0
%const %integer RMS ACT       = 16_1825A
%const %integer RMS DEL       = 16_18262
%const %integer RMS TEMP1     = 16_1826A
%const %integer RMS EOF       = 16_1827A
%const %integer RMS DNR       = 16_18272
%const %integer RMS FEX       = 16_18282
%const %integer RMS FLK       = 16_1828A
%const %integer RMS FNF       = 16_18292
%const %integer RMS PRV       = 16_1829A
%const %integer RMS RLK       = 16_182AA
%const %integer RMS REX       = 16_182A2
%const %integer RMS WLK       = 16_182BA
%const %integer RMS RNF       = 16_182B2
%const %integer RMS EXP       = 16_182C2
%const %integer RMS NMF       = 16_182CA
%const %integer RMS SUP       = 16_182D2
%const %integer RMS RSA       = 16_182DA
%const %integer RMS CRC       = 16_182E2
%const %integer RMS WCC       = 16_182EA
%const %integer RMS IDR       = 16_182F2
%const %integer RMS ABO       = 16_183EC
%const %integer RMS ALN       = 16_183FC
%const %integer RMS AID       = 16_183F4
%const %integer RMS ALQ       = 16_18404
%const %integer RMS ANI       = 16_1840C
%const %integer RMS BKS       = 16_1841C
%const %integer RMS AOP       = 16_18414
%const %integer RMS BKZ       = 16_18424
%const %integer RMS BLN       = 16_1842C
%const %integer RMS BUG       = 16_18434
%const %integer RMS BUG DDI   = 16_1843C
%const %integer RMS BUG DAP   = 16_18444
%const %integer RMS BUG XX2   = 16_1844C
%const %integer RMS BUG XX3   = 16_18454
%const %integer RMS BUG XX4   = 16_1845C
%const %integer RMS BUG XX5   = 16_18464
%const %integer RMS BUG XX6   = 16_1846C
%const %integer RMS BUG XX7   = 16_18474
%const %integer RMS BUG XX8   = 16_1847C
%const %integer RMS CAA       = 16_1848C
%const %integer RMS BUG XX9   = 16_18484
%const %integer RMS CCR       = 16_18494
%const %integer RMS CHG       = 16_1849C
%const %integer RMS COD       = 16_184AC
%const %integer RMS CHK       = 16_184A4
%const %integer RMS DAN       = 16_184BC
%const %integer RMS CUR       = 16_184B4
%const %integer RMS DIR       = 16_184CC
%const %integer RMS DEV       = 16_184C4
%const %integer RMS DME       = 16_184D4
%const %integer RMS DNA       = 16_184DC
%const %integer RMS DTP       = 16_184E4
%const %integer RMS DUP       = 16_184EC
%const %integer RMS ESA       = 16_184FC
%const %integer RMS DVI       = 16_184F4
%const %integer RMS FAB       = 16_1850C
%const %integer RMS ESS       = 16_18504
%const %integer RMS FLG       = 16_1851C
%const %integer RMS FAC       = 16_18514
%const %integer RMS FNM       = 16_1852C
%const %integer RMS FNA       = 16_18524
%const %integer RMS FSZ       = 16_18534
%const %integer RMS FOP       = 16_1853C
%const %integer RMS FUL       = 16_18544
%const %integer RMS IAL       = 16_1854C
%const %integer RMS IAN       = 16_18554
%const %integer RMS IDX       = 16_1855C
%const %integer RMS IFI       = 16_18564
%const %integer RMS IMX       = 16_1856C
%const %integer RMS IOP       = 16_18574
%const %integer RMS IRC       = 16_1857C
%const %integer RMS KBF       = 16_1858C
%const %integer RMS ISI       = 16_18584
%const %integer RMS KRF       = 16_1859C
%const %integer RMS KEY       = 16_18594
%const %integer RMS LAN       = 16_185AC
%const %integer RMS KSZ       = 16_185A4
%const %integer RMS LBL       = 16_185B4
%const %integer RMS LNE       = 16_185BC
%const %integer RMS LOC       = 16_185C4
%const %integer RMS MRN       = 16_185CC
%const %integer RMS NAM       = 16_185DC
%const %integer RMS MRS       = 16_185D4
%const %integer RMS NEF       = 16_185E4
%const %integer RMS NID       = 16_185EC
%const %integer RMS NPK       = 16_185FC
%const %integer RMS NOD       = 16_185F4
%const %integer RMS ORD       = 16_18604
%const %integer RMS ORG       = 16_1860C
%const %integer RMS PBF       = 16_18614
%const %integer RMS PLG       = 16_1861C
%const %integer RMS POS       = 16_18624
%const %integer RMS PRM       = 16_1862C
%const %integer RMS QUO       = 16_18634
%const %integer RMS RAB       = 16_1863C
%const %integer RMS RAC       = 16_18644
%const %integer RMS RAT       = 16_1864C
%const %integer RMS RFA       = 16_1865C
%const %integer RMS RBF       = 16_18654
%const %integer RMS RFM       = 16_18664
%const %integer RMS RHB       = 16_1866C
%const %integer RMS ROP       = 16_1867C
%const %integer RMS RLF       = 16_18674
%const %integer RMS RRV       = 16_18684
%const %integer RMS RVU       = 16_1868C
%const %integer RMS RST       = 16_1869C
%const %integer RMS RSS       = 16_18694
%const %integer RMS SEQ       = 16_186AC
%const %integer RMS RSZ       = 16_186A4
%const %integer RMS SIZ       = 16_186BC
%const %integer RMS SHR       = 16_186B4
%const %integer RMS STK       = 16_186CC
%const %integer RMS SQO       = 16_186C4
%const %integer RMS TRE       = 16_186DC
%const %integer RMS SYN       = 16_186D4
%const %integer RMS UBF       = 16_186EC
%const %integer RMS TYP       = 16_186E4
%const %integer RMS USZ       = 16_186F4
%const %integer RMS VER       = 16_186FC
%const %integer RMS XAB       = 16_1870C
%const %integer RMS VOL       = 16_18704
%const %integer RMS WSF       = 16_1871C
%const %integer RMS ESL       = 16_18714
%const %integer RMS ENV       = 16_18724
%const %integer RMS PLV       = 16_1872C
%const %integer RMS RSL       = 16_1873C
%const %integer RMS MBC       = 16_18734
%const %integer RMS NET       = 16_1874C
%const %integer RMS WLD       = 16_18744
%const %integer RMS IBF       = 16_18754
%const %integer RMS REF       = 16_1875C
%const %integer RMS IFL       = 16_18764
%const %integer RMS DFL       = 16_1876C
%const %integer RMS IBK       = 16_1877C
%const %integer RMS KNM       = 16_18774
%const %integer RMS LEX       = 16_1878C
%const %integer RMS KSI       = 16_18784
%const %integer RMS SNE       = 16_1879C
%const %integer RMS SEG       = 16_18794
%const %integer RMS UPI       = 16_187AC
%const %integer RMS SPE       = 16_187A4
%const %integer RMS STR       = 16_187BC
%const %integer RMS ACS       = 16_187B4
%const %integer RMS FTM       = 16_187C4
%const %integer RMS CRE       = 16_1C00A
%const %integer RMS ACC       = 16_1C002
%const %integer RMS ENT       = 16_1C01A
%const %integer RMS DAC       = 16_1C012
%const %integer RMS FND       = 16_1C02A
%const %integer RMS EXT       = 16_1C022
%const %integer RMS MKD       = 16_1C032
%const %integer RMS DPE       = 16_1C03A
%const %integer RMS SPL       = 16_1C042
%const %integer RMS DNF       = 16_1C04A
%const %integer RMS ATR       = 16_1C0CC
%const %integer RMS ATW       = 16_1C0D4
%const %integer RMS CCF       = 16_1C0DC
%const %integer RMS CHN       = 16_1C0EC
%const %integer RMS CDA       = 16_1C0E4
%const %integer RMS RMV       = 16_1C0FC
%const %integer RMS RER       = 16_1C0F4
%const %integer RMS SYS       = 16_1C10C
%const %integer RMS RPL       = 16_1C104
%const %integer RMS WPL       = 16_1C11C
%const %integer RMS WER       = 16_1C114
%const %integer RMS IFA       = 16_1C124
%const %integer RMS WBE       = 16_1C12C

%end %of %file
