! Imp Maths procedures
%external %long %real %fn %spec ARC COS (%long %real X)
%external %long %real %fn %spec ARC SIN (%long %real X)
%external %long %real %fn %spec ARC TAN (%long %real X, Y)
%external %long %real %fn %spec COS (%long %real X)
%external %long %real %fn %spec EXP (%long %real X)
%external %long %real %fn %spec LOG (%long %real X)
%external %long %real %fn %spec LOG TEN (%long %real X)
%external %long %real %fn %spec MOD (%long %real X)
%external %integer %fn %spec    RANDOM INTEGER
%external %long %real %fn %spec RANDOM REAL
%external %routine %spec        RESET RANDOMS
%external %long %real %fn %spec SIN (%long %real X)
%external %long %real %fn %spec SQRT (%long %real X)
%external %long %real %fn %spec TAN (%long %real X)

! Imp Maths Constants
%const %real PI = 3.14159265358
%const %real DtoR = 57.2958
%const %real  e = 2.7182818285

%end %of %file
