!
! $DSCDEF macro equivalent
!
! 1: data type codes
!
%const %integer DSC DTYPE Z     = 0  {specified no data type}
%const %integer DSC DTYPE V     = 1
%const %integer DSC DTYPE BU    = 2
%const %integer DSC DTYPE WU    = 3
%const %integer DSC DTYPE LU    = 4
%const %integer DSC DTYPE QU    = 5
%const %integer DSC DTYPE OU    = 25
%const %integer DSC DTYPE B     = 6
%const %integer DSC DTYPE W     = 7
%const %integer DSC DTYPE L     = 8
%const %integer DSC DTYPE Q     = 9
%const %integer DSC DTYPE O     = 26
%const %integer DSC DTYPE F     = 10
%const %integer DSC DTYPE D     = 11
%const %integer DSC DTYPE G     = 27
%const %integer DSC DTYPE H     = 28
%const %integer DSC DTYPE FC    = 12
%const %integer DSC DTYPE DC    = 13
%const %integer DSC DTYPE GC    = 29
%const %integer DSC DTYPE HC    = 30
%const %integer DSC DTYPE CIT   = 31
%const %integer DSC DTYPE VU    = 34
%const %integer DSC DTYPE T     = 14
%const %integer DSC DTYPE VT    = 37
%const %integer DSC DTYPE NU    = 15
%const %integer DSC DTYPE NL    = 16
%const %integer DSC DTYPE NLO   = 17
%const %integer DSC DTYPE NR    = 18
%const %integer DSC DTYPE NRO   = 19
%const %integer DSC DTYPE NZ    = 20
%const %integer DSC DTYPE P     = 21
%const %integer DSC DTYPE ZI    = 22
%const %integer DSC DTYPE ZEM   = 23
%const %integer DSC DTYPE DSC   = 24
%const %integer DSC DTYPE BPV   = 32
%const %integer DSC DTYPE BLV   = 33
%const %integer DSC DTYPE ADT   = 35
%const %integer DSC DTYPE CAD   = 178
%const %integer DSC DTYPE ENT   = 179
%const %integer DSC DTYPE GBL   = 180
%const %integer DSC DTYPE EPT   = 181
%const %integer DSC DTYPE R11   = 182
%const %integer DSC DTYPE FLD   = 183
%const %integer DSC DTYPE PCT   = 184
%const %integer DSC DTYPE DPC   = 185
%const %integer DSC DTYPE LBL   = 186
%const %integer DSC DTYPE SLB   = 187
%const %integer DSC DTYPE MOD   = 188
%const %integer DSC DTYPE EOM   = 189
%const %integer DSC DTYPE RTN   = 190
%const %integer DSC DTYPE EOR   = 191
!
! 2: descriptor class codes
!
%const %integer DSC CLASS Z     = 0
%const %integer DSC CLASS S     = 1
%const %integer DSC CLASS D     = 2
%const %integer DSC CLASS V     = 3
%const %integer DSC CLASS A     = 4
%const %integer DSC CLASS P     = 5
%const %integer DSC CLASS PI    = 6
%const %integer DSC CLASS J     = 7
%const %integer DSC CLASS JI    = 8
%const %integer DSC CLASS SD    = 9
%const %integer DSC CLASS NCA   = 10
%const %integer DSC CLASS VS    = 11
%const %integer DSC CLASS VSA   = 12
%const %integer DSC CLASS UBS   = 13
%const %integer DSC CLASS UBA   = 14
%const %integer DSC CLASS BFA   = 191
!
! 3: descriptor record format
!
%record %format Dsc Fm ( %short Length, %byte Dtype, Class,
                         %integer Pointer )

%end %of %file
