%external %integer %function %spec Open Uaf
%external %integer %function %spec Close Uaf
%external %integer %function %spec Uaf Uic Locate ( %integer Uic )
%external %integer %function %spec Uaf User Locate ( %string(255) User Name )
%external %integer %function %spec Uaf Locate Next
%external %string(255) %function %spec Uaf Dir
%external %string(255) %function %spec Uaf Dev
%external %integer %function %spec Uaf Mail
%external %integer %function %spec Uaf Add Mail
%external %string(255) %function %spec Uaf Data
%external %integer %function %spec Uaf Add Data ( %string(255) S )
%external %integer %function %spec Uaf Uic
%external %routine %spec Uaf Priv ( %integer %name Priv Quadword )
%external %string(255) %function %spec Uaf User Name
%external %string(255) %function %spec Uaf Account
%external %string(255) %function %spec Uaf Owner
%external %integer %function %spec Uaf Add Owner ( %string(255) S )
%external %predicate %spec Check Password ( %string(255) S )
%external %integer %function %spec UAF Logfails
%end %of %file
