!
! IMP equivalent of the $WSLDEF macro
!
!
! Working set list entry format
!
!  31               9 8 7 6 5 4 3   1 0
! +------------------+-+-+-+-+-+-----+-+
! | VP number        | |X| | | |     | |
! +------------------+-+-+-+-+-+-----+-+
!                     |   | | |   |   |
! Saved modify bit ---+   | | |   |   |
! Goodpage bit -----------+ | |   |   |
! Locked in WS -------------+ |   |   |
! Locked in memory -----------+   |   |
! Page type ----------------------+   |
! WSL entry valid --------------------+
!
%const %integer WSL C LENGTH   = 4 {length of a WSL entry}

!
! Flag bits
!
%const %integer WSL M VALID    = 2_0 0 0 0 0 000 1,
                WSL M PAGTYP   = 2_0 0 0 0 0 111 0,  WSL S PAGTYP = 3,
                                                     WSL V PAGTYP = 1,
                WSL M PFNLOCK  = 2_0 0 0 0 1 000 0,
                WSL M WSLOCK   = 2_0 0 0 1 0 000 0,
                WSL M GOODPAGE = 2_0 0 1 0 0 000 0,
                WSL M MODIFY   = 2_1 0 0 0 0 000 0

!
! Page type field values
!
%const %integer WSL C PROCESS  = 0,
                WSL C SYSTEM   = 1,
                WSL C GLOBAL   = 2,
                WSL C GBLWRT   = 3,
                WSL C PPGTBL   = 4,
                WSL C GPGTBL   = 5
