!
! >>> CLIMSG <<<
!
%const %integer CLI ABVERB     = 16_00038008
%const %integer CLI ABKEYW     = 16_00038010
%const %integer CLI BUFOVF     = 16_00038018
%const %integer CLI COMPLX     = 16_00038020
%const %integer CLI DEFOVF     = 16_00038028
%const %integer CLI DIRECT     = 16_00038030
%const %integer CLI EXPSYN     = 16_00038038
%const %integer CLI IMCHNG     = 16_00038040
%const %integer CLI INSFPRM    = 16_00038048
%const %integer CLI IVCHAR     = 16_00038050
%const %integer CLI SPARE1     = 16_00038058
%const %integer CLI IVKEYW     = 16_00038060
%const %integer CLI IVOPER     = 16_00038068
%const %integer CLI IVPROT     = 16_00038070
%const %integer CLI IVQLOC     = 16_00038078
%const %integer CLI IVSYMB     = 16_00038080
%const %integer CLI IVVALU     = 16_00038088
%const %integer CLI IVVERB     = 16_00038090
%const %integer CLI MAXPARM    = 16_00038098
%const %integer CLI NOATFIL    = 16_000380A0
%const %integer CLI NOCCAT     = 16_000380A8
%const %integer CLI NOCOMD     = 16_000380B0
%const %integer CLI NOKEYW     = 16_000380B8
%const %integer CLI NOLIST     = 16_000380C0
%const %integer CLI NOQUAL     = 16_000380C8
%const %integer CLI NOVALU     = 16_000380D0
%const %integer CLI NOTNEG     = 16_000380D8
%const %integer CLI NULFIL     = 16_000380E0
%const %integer CLI NUMBER     = 16_000380E8
%const %integer CLI ONCOMD     = 16_000380F0
%const %integer CLI ONERR      = 16_000380F8
%const %integer CLI ONLEVL     = 16_00038100
%const %integer CLI ONOVF      = 16_00038108
%const %integer CLI PARMDEL    = 16_00038110
%const %integer CLI RSLOVF     = 16_00038118
%const %integer CLI SKPDAT     = 16_00038120
%const %integer CLI STKOVF     = 16_00038128
%const %integer CLI SYMDEL     = 16_00038130
%const %integer CLI SYMOVF     = 16_00038138
%const %integer CLI UNDSYM     = 16_00038140
%const %integer CLI USGOTO     = 16_00038148
%const %integer CLI VALREQ     = 16_00038150
%const %integer CLI ONEVAL     = 16_00038158
%const %integer CLI OVRFLW     = 16_00038160
%const %integer CLI UNPROQUAL  = 16_00038168
%const %integer CLI UNPROPARM  = 16_00038170
%const %integer CLI INVKEY     = 16_00038178
%const %integer CLI INVRSP     = 16_00038180
%const %integer CLI UNDFIL     = 16_00038188
%const %integer CLI FILOPN     = 16_00038190
%const %integer CLI BADRET     = 16_00038198
%const %integer CLI ABSYMD     = 16_000381A0
%const %integer CLI INVUIC     = 16_000381A8
%const %integer CLI BADTEXT    = 16_000381B0
%const %integer CLI ABFNAM     = 16_000381B8
%const %integer CLI IVFNAM     = 16_000381C0
%const %integer CLI BLKOVRFLOW = 16_000381C8
%const %integer CLI BLKUNDFLOW = 16_000381D0
%const %integer CLI BADBLK     = 16_000381D8
%const %integer CLI NOLBLS     = 16_000381E0
%const %integer CLI INSPRIV    = 16_000381E8
%const %integer CLI ABSENT     = 16_000381F0
%const %integer CLI NEGATED    = 16_000381F8
%const %integer CLI INVFILSPE  = 16_00038200
%const %integer CLI INVLOGFIL  = 16_00038208
%const %integer CLI INVIFTHEN  = 16_00038210
%const %integer CLI SYMTOOLNG  = 16_00038218
%const %integer CLI ASTDCL     = 16_00038220
%const %integer CLI INVRANGE   = 16_00038228
%const %integer CLI CONFQUAL   = 16_00038802
%const %integer CLI INVQUAL    = 16_0003880A
%const %integer CLI REQPRMABS  = 16_00038812
%const %integer CLI INVQUALNUM = 16_0003881A
%const %integer CLI INVREQTYP  = 16_00038822
%const %integer CLI NOVALUE    = 16_0003882A
%const %integer CLI VALCNVERR  = 16_00038832
%const %integer CLI ILLVAL     = 16_0003883A
%const %integer CLI NOOPTPRS   = 16_00038842
%const %integer CLI CREQUEJOB  = 16_0003884A
%const %integer CLI SUBMITERR  = 16_00038852
%const %integer CLI DEVALSPL   = 16_0003885A
%const %integer CLI DEVNOTSPL  = 16_00038862
%const %integer CLI IVDEVTYPE  = 16_0003886A
%const %integer CLI IMGFNF     = 16_00038872
%const %integer CLI DEVNOTFOR  = 16_0003887A
%const %integer CLI PWDNOTVAL  = 16_00038882
%const %integer CLI PWDNOTVER  = 16_0003888A
%const %integer CLI PWDLOCKED  = 16_00038892
%const %integer CLI NOTFR      = 16_0003889A
%const %integer CLI PWDSYNTAX  = 16_000388A2
%const %integer CLI IMGNAME    = 16_000388AA
%const %integer CLI IMAGEFNF   = 16_000388B2
%const %integer CLI BADSTRLVL  = 16_000388BA
%const %integer CLI REFUSED    = 16_000388C2
%const %integer CLI BADCTLMSK  = 16_000388CA
%const %integer CLI INVRFM     = 16_000388D2
%const %integer CLI NOCLINT    = 16_000388DA
%const %integer CLI NOSPAWN    = 16_000388E2
%const %integer CLI SPWNIO     = 16_000388EA
%const %integer CLI TRMMBX     = 16_000388F2
%const %integer CLI SPAWNED    = 16_0003FD01
%const %integer CLI ATTACHED   = 16_0003FD09
%const %integer CLI RETURNED   = 16_0003FD11
!for now!%const %integer CLI PRESENT    = 16_0003FD19
%const %integer CLI DEFAULTED  = 16_0003FD21
%const %integer CLI CONCAT     = 16_0003FD29
%const %integer CLI PROC ID    = 16_0003FFF1
%const %integer CLI QUEJOBCRE  = 16_0003FFF9
%const %integer CLI NORMAL     = 16_00030001

%end %of %file
