!
! Baud rates
!
%const %integer TT C BAUD 50             = 1,
                TT C BAUD 75             = 2,
                TT C BAUD 110            = 3,
                TT C BAUD 134            = 4,
                TT C BAUD 150            = 5,
                TT C BAUD 300            = 6,
                TT C BAUD 600            = 7,
                TT C BAUD 1200           = 8,
                TT C BAUD 1800           = 9,
                TT C BAUD 2000           = 10,
                TT C BAUD 2400           = 11,
                TT C BAUD 3600           = 12,
                TT C BAUD 4800           = 13,
                TT C BAUD 7200           = 14,
                TT C BAUD 9600           = 15,
                TT C BAUD 19200          = 16

!
! Terminal types
!
%const %integer TT  UNKNOWN              = 0,
                TT  VT05                 = 1,
                TT  VK100                = 2,
                TT  VT173                = 3,
                TT  FT1                  = 16,
                TT  FT2                  = 17,
                TT  FT3                  = 18,
                TT  FT4                  = 19,
                TT  FT5                  = 20,
                TT  FT6                  = 21,
                TT  FT7                  = 22,
                TT  FT8                  = 23,
                TT  LAX                  = 32,
                TT  LA36                 = 32,
                TT  LA120                = 33,
                TT  LA34                 = 34,
                TT  LA38                 = 35,
                TT  LA12                 = 36,
                TT  LA100                = 37,
                TT  LA24                 = 37,
                TT  LQP02                = 38,
                TT  VT5X                 = 64,
                TT  VT52                 = 64,
                TT  VT55                 = 65,
                TT  VT100                = 96,
                TT  VT101                = 97,
                TT  VT102                = 98,
                TT  VT105                = 99,
                TT  VT125                = 100,
                TT  VT131                = 101,
                TT  VT132                = 102

!
! device dependent characteristics
!
%const %integer TT M PASSALL             = 1,
                TT M NOECHO              = 2,
                TT M NOTYPEAHD           = 4,
                TT M ESCAPE              = 8,
                TT M HOSTSYNC            = 16,
                TT M TTSYNC              = 32,
                TT M SCRIPT              = 64,
                TT M LOWER               = 128,
                TT M MECHTAB             = 256,
                TT M WRAP                = 16_200,
                TT M CRFILL              = 16_400,
                TT M LFFILL              = 16_800,
                TT M SCOPE               = 16_1000,
                TT M REMOTE              = 16_2000,
                TT M HOLDSCREEN          = 16_4000,
                TT M EIGHTBIT            = 16_8000,
                TT M MBXDSABL            = 16_10000,
                TT M NOBRDCST            = 16_20000,
                TT M READSYNC            = 16_40000,
                TT M MECHFORM            = 16_80000,
                TT M HALFDUP             = 16_100000,
                TT M MODEM               = 16_200000,
                TT M OPER                = 16_400000,
                TT M PAGE                = 16_FF000000

%const %integer TT M ALTRPAR             = 32,
                TT M PARITY              = 64,
                TT M ODD                 = 128

%const %integer TT M DS DTR              = 2,
                TT M DS SECTX            = 8,
                TT M DS RTS              = 16,
                TT M DS SECREC           = 8,
                TT M DS CTS              = 16,
                TT M DS CARRIER          = 32,
                TT M DS RING             = 64,
                TT M DS DSR              = 128

%end %of %file
