!
! IMP equivalent of the $DCDEF macro
!
%const %integer AT MBA        = 0
%const %integer AT UBA        = 1
%const %integer AT DR         = 2
%const %integer AT MPM        = 3
%const %integer AT CI         = 4
%const %integer AT NULL       = 5
%const %integer DC DISK       = 1
%const %integer DC TAPE       = 2
%const %integer DC SCOM       = 32
%const %integer DC CARD       = 65
%const %integer DC TERM       = 66
%const %integer DC LP         = 67
%const %integer DC REALTIME   = 96
%const %integer DC BUS        = 128
%const %integer DC MAILBOX    = 160
%const %integer DC JOURNAL    = 161
%const %integer DC MISC       = 200


%const %integer DT RK06       = 1
%const %integer DT RK07       = 2
%const %integer DT RP04       = 3
%const %integer DT RP05       = 4
%const %integer DT RP06       = 5
%const %integer DT RM03       = 6
%const %integer DT RP07       = 7
%const %integer DT RP07HT     = 8
%const %integer DT RL01       = 9
%const %integer DT RL02       = 10
%const %integer DT RX02       = 11
%const %integer DT RX04       = 12
%const %integer DT RM80       = 13
%const %integer DT TU58       = 14
%const %integer DT RM05       = 15
%const %integer DT RX01       = 16
%const %integer DT ML11       = 17
%const %integer DT RB02       = 18
%const %integer DT RB80       = 19
%const %integer DT RA80       = 20
%const %integer DT RA81       = 21
%const %integer DT RA60       = 22
%const %integer DT RZ01       = 23
%const %integer DT RZF01      = 24
%const %integer DT TE16       = 1
%const %integer DT TU45       = 2
%const %integer DT TU77       = 3
%const %integer DT TS11       = 4
%const %integer DT TU78       = 5
%const %integer DT TTYUNKN    = 0
%const %integer DT VT05       = 1
%const %integer DT FT1        = 16
%const %integer DT FT2        = 17
%const %integer DT FT3        = 18
%const %integer DT FT4        = 19
%const %integer DT FT5        = 20
%const %integer DT FT6        = 21
%const %integer DT FT7        = 22
%const %integer DT FT8        = 23
%const %integer DT LAX        = 32
%const %integer DT LA36       = 32
%const %integer DT LA120      = 33
%const %integer DT VT5X       = 64
%const %integer DT VT52       = 64
%const %integer DT VT55       = 65
%const %integer DT VT100      = 96
%const %integer DT VK100      = 2
%const %integer DT VT173      = 3
%const %integer DT LA34       = 34
%const %integer DT LA38       = 35
%const %integer DT LA12       = 36
%const %integer DT LA24       = 37
%const %integer DT LA100      = 37
%const %integer DT LQP02      = 38
%const %integer DT VT101      = 97
%const %integer DT VT102      = 98
%const %integer DT VT105      = 99
%const %integer DT VT125      = 100
%const %integer DT VT131      = 101
%const %integer DT VT132      = 102
%const %integer DT DZ11       = 66
%const %integer DT DZ32       = 67
%const %integer DT DZ730      = 68
%const %integer DT DMC11      = 1
%const %integer DT DMR11      = 2
%const %integer DT XK 3271    = 3
%const %integer DT XJ 2780    = 4
%const %integer DT NW X25     = 5
%const %integer DT NV X29     = 6
%const %integer DT SB ISB11   = 7
%const %integer DT MX MUX200  = 8
%const %integer DT DMP11      = 9
%const %integer DT DMF32      = 10
%const %integer DT XV 3271    = 11
%const %integer DT CI         = 12
%const %integer DT NI         = 13
%const %integer DT UNA11      = 14
%const %integer DT YN X25     = 15
%const %integer DT YO X25     = 16
%const %integer DT YP ADCCP   = 17
%const %integer DT YQ 3271    = 18
%const %integer DT YR DDCMP   = 19
%const %integer DT YS SDLC    = 20
%const %integer DT LP11       = 1
%const %integer DT LA11       = 2
%const %integer DT LA180      = 3

%const %integer DT CR11       = 1

%const %integer DT MBX        = 1
%const %integer DT LPA11      = 1
%const %integer DT DR780      = 2
%const %integer DT DR750      = 3
%const %integer DT DR11W      = 4
%const %integer DT PCL11R     = 5
%const %integer DT PCL11T     = 6
%const %integer DT DR11C      = 7
%const %integer DT XI DR11C   = 8


%const %integer DT CI780      = 1
%const %integer DT CI750      = 2
%const %integer DT UDA50      = 3

%const %integer DT UNKNJNL    = 0
%const %integer DT RUJNL      = 1
%const %integer DT BIJNL      = 2
%const %integer DT AIJNL      = 3
%const %integer DT ATJNL      = 4

%const %integer DT DN11       = 1

%end %of %file
