%external %integer %function %spec EBCDIC to ISO ( %integer EBCDIC )
%external %integer %function %spec ISO to EBCDIC ( %integer ISO    )
%external          %routine  %spec Select EBCDIC ( %integer Which  )
%external          %routine  %spec Dump Table
%external          %routine  %spec Dump Tables
%external %integer           %spec Ebcdic Conversion Errors

%const %integer International EBCDIC = 1,
                Moho          EBCDIC = 2,
                ERCC          EBCDIC = 3,
                Electromask   EBCDIC = 4

%end %of %file
