!
! IMP diagnostic timer module
!
%external %routine %spec Timer Start   %alias "IMP_TIMER_START"
%external %routine %spec Timer Output  %alias "IMP_TIMER_OUTPUT" (%integer I)
%external %routine %spec Timer Step    %alias "IMP_TIMER_STEP"   (%string(31) S)
%external %routine %spec Timer Total   %alias "IMP_TIMER_TOTAL"  (%string(31) S)
%external %routine %spec Timer Enable  %alias "IMP_TIMER_ENABLE"
%external %routine %spec Timer Disable %alias "IMP_TIMER_DISABLE"

%end %of %file
