!
! IMP equivalent of the $SMRDEF macro
!
! Defines symbiont manager function and option codes.
!
%const %integer -
      SMR K INITIAL   = 16_00,
      SMR K DELETE    = 16_01,
      SMR K START     = 16_02,
      SMR K PAUSE     = 16_03,
      SMR K MERGE     = 16_04,
      SMR K REDIRECT  = 16_05,
      SMR K JUSTIFY   = 16_06,
      SMR K STOP      = 16_07,
      SMR K ENTER     = 16_08,
      SMR K CREJOB    = 16_09,
      SMR K ADDFIL    = 16_0A,
      SMR K CLSJOB    = 16_0B,
      SMR K RMVJOB    = 16_0C,
      SMR K ALTER     = 16_0D,
      SMR K ABORT     = 16_0E,
      SMR K RELEASE   = 16_0F

%const %integer -
      SMR K DETINIT   = 16_10,
      SMR K SYNCJOB   = 16_11,
      SMR K ASKQNAM   = 16_12

%const %integer -
      SMO K DELETE    = 16_01,
      SMO K BRSTPAG   = 16_02,
      SMO K NOBRSTPAG = 16_03,
      SMO K FLAGPAG   = 16_04,
      SMO K NOFLAGPAG = 16_05,
      SMO K PAGHDR    = 16_06,
      SMO K DOUBLE    = 16_07,
      SMO K NOFEED    = 16_08,
      SMO K PAGCNT    = 16_09,
      SMO K COPIES    = 16_0A,
      SMO K FILESIZ   = 16_0B,
      SMO K DESTQUE   = 16_0C

%const %integer -
      SMO K RLSTIM    = 16_20,
      SMO K HOLD      = 16_21,
      SMO K JOBPRI    = 16_22,
      SMO K JOBCOPY   = 16_23,
      SMO K FORMTYPE  = 16_24,
      SMO K LOWER     = 16_25,
      SMO K PARAMS    = 16_26,
      SMO K JOBNAME   = 16_27,
      SMO K NOLOWER   = 16_28,
      SMO K CPULIM    = 16_29,
      SMO K NOCPULM   = 16_2A,
      SMO K WSQUOTA   = 16_2B,
      SMO K NOWSQUO   = 16_2C,
      SMO K WSDEFLT   = 16_2D,
      SMO K NOWSDFT   = 16_2E,
      SMO K DQCHAR    = 16_2F

%const %integer -
      SMO K LOGFNAM   = 16_30,
      SMO K LOGQNAM   = 16_31,
      SMO K KEEPLOG   = 16_32,
      SMO K NOSPOOL   = 16_33,
      SMO K NOKEEPLOG = 16_34,
      SMO K NOLOG     = 16_35,
      SMO K NOTIFY    = 16_36,
      SMO K NONOTFY   = 16_37,
      SMO K WSEXTNT   = 16_38,
      SMO K NOWSEXTNT = 16_39

%const %integer -
      SMO K CURFORM   = 16_40,
      SMO K GENPRT    = 16_41,
      SMO K NOGENPRT  = 16_42,
      SMO K DETJOB    = 16_43,
      SMO K GENDEV    = 16_44,
      SMO K NOGENDEV  = 16_45,
      SMO K DEFBRST   = 16_46,
      SMO K NODEFBRST = 16_47,
      SMO K DEFFLAG   = 16_48,
      SMO K NODEFFLAG = 16_49,
      SMO K TRMDEV    = 16_4A,
      SMO K NOTRMDEV  = 16_4B,
      SMO K JOBLIM    = 16_4C,
      SMO K INIPRI    = 16_4D,
      SMO K DISWAP    = 16_4E,
      SMO K MCPULM    = 16_4F

%const %integer -
      SMO K NOMCPULM  = 16_50,
      SMO K DCPULM    = 16_51,
      SMO K NODCPULM  = 16_52,
      SMO K WSQUTA    = 16_53,
      SMO K NOWSQUTA  = 16_54,
      SMO K WSDFLT    = 16_55,
      SMO K NOWSDFLT  = 16_56,
      SMO K CURDQCHAR = 16_57,
      SMO K SMBNAME   = 16_58,
      SMO K WSXTANT   = 16_59,
      SMO K NOWSXTNT  = 16_5A,
      SMO K NODISWAP  = 16_5B

%const %integer -
      SMO K NEXTJOB   = 16_60,
      SMO K TOPOFILE  = 16_61,
      SMO K SPCCNT    = 16_62

%const %integer -
      SMO K REQUEUE   = 16_70,
      SMO K REQDEST   = 16_71,
      SMO K REQPRIO   = 16_72
