%const %integer SHR APPENDEDB    = 4096
%const %integer SHR APPENDEDR    = 4104
%const %integer SHR BADBYTE      = 4112
%const %integer SHR BADFIELD     = 4120
%const %integer SHR BADLONG      = 4128
%const %integer SHR BADWORD      = 4136
%const %integer SHR BEGIN        = 4144
%const %integer SHR BEGIND       = 4152
%const %integer SHR BEGINT       = 4160
%const %integer SHR CLICB        = 4168
%const %integer SHR CLOSEIN      = 4176
%const %integer SHR CLOSEOUT     = 4184
%const %integer SHR COPIEDB      = 4192
%const %integer SHR COPIEDR      = 4200
%const %integer SHR CREATED      = 4208
%const %integer SHR ENDED        = 4216
%const %integer SHR ENDEDD       = 4224
%const %integer SHR ENDEDT       = 4232
%const %integer SHR NEWFILES     = 4240
%const %integer SHR OPENIN       = 4248
%const %integer SHR OPENOUT      = 4256
%const %integer SHR OVERLAY      = 4264
%const %integer SHR READERR      = 4272
%const %integer SHR REPLACED     = 4280
%const %integer SHR WILDCONCAT   = 4288
%const %integer SHR WILDOUTVER   = 4296
%const %integer SHR WRITEERR     = 4304
%const %integer SHR ABEND        = 4312
%const %integer SHR ABENDD       = 4320
%const %integer SHR ABENDT       = 4328
%const %integer SHR SYSERRORPC   = 4336
%const %integer SHR SYNTAX       = 4344
%const %integer SHR NOVALUE      = 4352
%const %integer SHR BADKEY       = 4360
%const %integer SHR BADVALUE     = 4368
%const %integer SHR BADDELIM     = 4376
%const %integer SHR BADLOGIC     = 4384
%const %integer SHR NOWILD       = 4392
%const %integer SHR TEXT         = 4400
%const %integer SHR IDXCONCAT    = 4408
%const %integer SHR RELCONCAT    = 4416
%const %integer SHR HIGHVER      = 4424
%const %integer SHR BADLOGICPC   = 4432
%const %integer SHR ATPC         = 4440
%const %integer SHR BADCOPIES    = 4448
%const %integer SHR BADFORM      = 4456
%const %integer SHR BADJOBID     = 4464
%const %integer SHR BADJOBNAME   = 4472
%const %integer SHR BADPRTY      = 4480
%const %integer SHR BADQNAME     = 4488
%const %integer SHR BADTIME      = 4496
%const %integer SHR NOQUEUE      = 4504
%const %integer SHR NOJOBID      = 4512
%const %integer SHR NOJOBNAME    = 4520
%const %integer SHR SYSERROR     = 4528
%const %integer SHR NOTCOPIED    = 4536
%const %integer SHR NOTCMPLT     = 4544
%const %integer SHR RMSERROR     = 4552
%const %integer SHR UNXPCTSTS    = 4560
%const %integer SHR HASHCONCAT   = 4568
%const %integer SHR INCOMPAT     = 4576
%const %integer SHR VALERR       = 4584
%const %integer SHR FILNOTDEL    = 4592
%const %integer SHR CONFDEL      = 4600
%const %integer SHR DELETED      = 4608
%const %integer SHR DELVER       = 4616
%const %integer SHR PURGEVER     = 4624
%const %integer SHR CLOSEDEL     = 4632
%const %integer SHR DIRTOOBUS    = 4640
%const %integer SHR NOFILPURG    = 4648
%const %integer SHR FILNOTPUR    = 4656
%const %integer SHR SEARCHFAIL   = 4664
%const %integer SHR DELINTERR    = 4672
%const %integer SHR PARSEFAIL    = 4680
%const %integer SHR FILPURGED    = 4688
%const %integer SHR ENDABORT     = 4696
%const %integer SHR ENDDIAGS     = 4704
%const %integer SHR ENDNOOBJ     = 4712
%const %integer SHR HALTED       = 4720
%const %integer SHR NOCMDMEM     = 4728
%const %integer SHR QEMPTY       = 4736
%const %integer SHR CBT          = 4744
%const %integer SHR EXISTS       = 4752
%const %integer SHR UNLOCKED     = 4760
%const %integer SHR RENAMED      = 4768
%const %integer SHR PROTECTED    = 4776
%const %integer SHR NOTLOCKED    = 4784
%const %integer SHR ACTIMAGE     = 4792
%const %integer SHR DIRNOTCRE    = 4800
%const %integer SHR NODESTQUE    = 4808
%const %integer SHR ILLDESQUE    = 4816
%const %integer SHR NOTTERM      = 4824
%const %integer SHR CONFQUAL     = 4832
%const %integer SHR ILLDIRCOPY   = 4840
%const %integer SHR INSVIRMEM    = 4848
%const %integer SHR CREATEDSTM   = 4856
%const %integer SHR NOTRUNC      = 4864

%end %of %file
