!
! Logical name services
!
%external %integer %function %spec CRELOG %alias "IMP_CRELOG" ( %c
          %integer Tblflg, %string(63) Lognam, Eqlnam, %integer Acmode )

%external %integer %function %spec DELLOG %alias "IMP_DELLOG" ( %c
          %integer Tblflg, %string(63) Lognam, %integer Acmode )

%external %integer %function %spec TRNLOG %alias "IMP_TRNLOG" ( %c
          %string(63) Lognam, %string(*) %name Rslbuf,
          %byte %name Table, Acmode, %integer Dsbmsk )

!
! RTL interface
!
%external %integer %function %spec SET LOGICAL %alias "IMP_SET_LOGICAL" ( %c
                           %string(63) Lognam, Eqlnam )

%external %string(127) %function %spec Translate ( %string(127) S )
