%external %integer %function %spec SET SYMBOL %alias "IMP_SET_SYMBOL" ( %c
                   %string(255) Symbol, Value, %integer Table )

%external %integer %function %spec GET SYMBOL %alias "IMP_GET_SYMBOL" ( %c
                   %string(255) Symbol, %string(*) %name Retbuf,
                   %integer %name Tblind )
