%external %integer %function %spec ASCEFC %alias "IMP_ASCEFC" ( %c
                   %integer Efn, %string(255) Cluster Name,
                   %integer Prot, Perm )

%external %integer %function %spec DLCEFC %alias "IMP_DLCEFC" ( %c
                   %string(255) Cluster Name )

%system %integer %function %spec CLREF  ( %integer EFN )
%system %integer %function %spec SETEF  ( %integer EFN )
%system %integer %function %spec WAITFR ( %integer EFN )
%system %integer %function %spec DACEFC ( %integer EFN )
%system %integer %function %spec WFLAND ( %integer EFN, %integer MASK )
%system %integer %function %spec WFLOR  ( %integer EFN, %integer MASK )
%system %integer %function %spec READEF ( %integer EFN, %integer %name STATE )

%end %of %file
