!
! use the following two routines only if you must!
!
! Status values are to be found in Imp_Include:CLIMSG.Inc
!
%external %integer     %function %spec Cli Present       ( %string(63) Label )
%external %integer     %function %spec Cli Value         ( %string(63) Label,
                                                           %string(*) %name V )
%external %routine               %spec Cli End Parse %alias "CLI$END_PARSE"

!
! Normally, programs will use the following:
!
%external %predicate             %spec Qualifier Present ( %string(63) Label )
%external %integer     %function %spec Qualifier I       ( %string(63) Label )
%external %string(127) %function %spec Qualifier S       ( %string(63) Label )
%external %long %real  %function %spec Qualifier R       ( %string(63) Label )
%endoffile
