%external %routine %spec Connect File ( %string(255) File,
                                        %integer Writeable,
                                        %integer %name Start Addr,
                                                       Bytes Mapped )

%external %routine %spec Make File    ( %string(255) File,
                                        %integer Pages,
                                        %integer %name Start Addr )

%external %routine %spec Disconnect File %alias "IMP_DISCONNECT_FILE" %c
                                      ( %integer File Base Addr )

{values for Writeable}
%const %integer Read Only       = 0, {section not writeable}
                Read Write      = 1, {section writeable, file affected}
                Read Write Temp = 2  {changes do not affect file}

%end %of %file
