!
! Imp equivalent of the VMS $STATEDEF macro
!
%const %integer SCH C COLPG    = 16_1, {collided page fault wait}
                SCH C MWAIT    = 16_2, {misc resource and mutex waits}
                SCH C CEF      = 16_3, {common event flag wait}
                SCH C PFW      = 16_4, {page fault wait}
                SCH C LEF      = 16_5, {local event flag wait}
                SCH C LEFO     = 16_6, {local event flag wait, outswapped}
                SCH C HIB      = 16_7, {hibernate wait}
                SCH C HIBO     = 16_8, {hibernate wait, outswapped}
                SCH C SUSP     = 16_9, {suspended}
                SCH C SUSPO    = 16_A, {suspended, outswapped}
                SCH C FPG      = 16_B, {free page wait}
                SCH C COM      = 16_C, {compute wait}
                SCH C COMO     = 16_D, {compute wait, outswapped}
                SCH C CUR      = 16_E  {current process}
