%record %format Quota Fm ( %integer Flags, Uic, Usage,
                           %integer Perm Quota, Overdraft )
%external %record(Quota Fm) %spec Quota Record %alias "Quota_Rec"
%external %integer %function %spec Fetch Quota ( %string(15) Dev, %integer Uic )
%end %of %file
