%end %of %list
%const %integer   NUL  =  0,   SOH  =  1,   STX  =  2,   ETX  =  3
%const %integer   EOT  =  4,   ENQ  =  5,   ACK  =  6,   BEL  =  7
%const %integer   BS   =  8,   HT   =  9,   LF   = 10,   VT   = 11
%const %integer   FF   = 12,   CR   = 13,   SO   = 14,   SI   = 15
%const %integer   DLE  = 16,   DC1  = 17,   DC2  = 18,   DC3  = 19
%const %integer   DC4  = 20,   NAK  = 21,   SYN  = 22,   ETB  = 23
%const %integer   CAN  = 24,   EM   = 25,   SUB  = 26,   ESC  = 27
%const %integer   FS   = 28,   GS   = 29,   RS   = 30,   US   = 31
%const %integer   DEL  = 127
%const %integer   TAB  = HT
%list
%end %of %file
