! specs for exit handler
%external %routine %spec Declare Exit Handler %alias "IMP$DCLEXH" %c
        ( %routine Handler ( %integer %name Reason ) )
%own %integer Curse You Robertson = 17 {"fix" compiler bug}
%end %of %file
