!
! IMP equivalent of $JPIDEF macro
!

%record %format JPI Item Fm ( %short Buflen, Itemcode,
                              %integer Bufadr,
                              %shortinteger %name Retlen )

%const %integer   %c
      JPI C LISTEND  = 16_00000000,
      JPI C ADRTYPE  = 16_00000001,
      JPI C CTLTYPE  = 16_00000002,
      JPI C PCBTYPE  = 16_00000003,
      JPI C PHDTYPE  = 16_00000004

%const %integer   %c
      JPI EXCVEC     = 16_100, {address}
      JPI FINALEXC   = 16_101, {address}
      JPI LASTADR    = 16_102

%const %integer   %c
      JPI VIRTPEAK   = 16_200, {value}
      JPI WSPEAK     = 16_201, {value}
      JPI USERNAME   = 16_202, {string(12) blank-filled}
      JPI ACCOUNT    = 16_203, {string(8)  blank-filled}
      JPI PROCPRIV   = 16_204, {quadword value}
      JPI VOLUMES    = 16_205, {value}
      JPI LOGINTIM   = 16_206, {quadword value}
      JPI IMAGNAME   = 16_207, {string(128)}
      JPI SITESPEC   = 16_208, {value}
      JPI LASTCTL    = 16_209

%const %integer   %c
      JPI ASTACT     = 16_300, {value}
      JPI ASTEN      = 16_301, {value}
      JPI PRI        = 16_302, {value}
      JPI OWNER      = 16_303, {value}
      JPI UIC        = 16_304, {value}
      JPI STS        = 16_305, {value}
      JPI STATE      = 16_306, {value}
      JPI MEM        = 16_307, {value}
      JPI GRP        = 16_308, {value}
      JPI PRIB       = 16_309, {value}
      JPI APTCNT     = 16_30A, {value}
      JPI TMBU       = 16_30B, {value}
      JPI GPGCNT     = 16_30C, {value}
      JPI PPGCNT     = 16_30D, {value}
      JPI ASTCNT     = 16_30E, {value}
      JPI BIOCNT     = 16_30F, {value}
      JPI BIOLM      = 16_310, {value}
      JPI BYTCNT     = 16_311, {value}
      JPI DIOCNT     = 16_312, {value}
      JPI DIOLM      = 16_313, {value}
      JPI FILCNT     = 16_314, {value}
      JPI TQCNT      = 16_315, {value}
      JPI EFWM       = 16_316, {value}
      JPI EFCS       = 16_317, {value}
      JPI EFCU       = 16_318, {value}
      JPI PID        = 16_319, {value}
      JPI BYTLM      = 16_31A, {value}
      JPI PRCCNT     = 16_31B, {value}
      JPI PRCNAM     = 16_31C, {string(15) blank-filled}
      JPI TERMINAL   = 16_31D, {string(7)  blank-filled}
      JPI JOBPRCCNT  = 16_31E, {value}
      JPI ENQCNT     = 16_31F, {value}
      JPI ENQLM      = 16_320, {value}
      JPI SWPFILLOC  = 16_321, {value}
      JPI LASTPCB    = 16_322

%const %integer   %c
      JPI CURPRIV    = 16_400, {quadword value}
      JPI WSAUTH     = 16_401, {value}
      JPI WSQUOTA    = 16_402, {value}
      JPI DFWSCNT    = 16_403, {value}
      JPI FREP0VA    = 16_404, {value}
      JPI FREP1VA    = 16_405, {value}
      JPI DFPFC      = 16_406, {value}
      JPI CPUTIM     = 16_407, {quadword value}
      JPI PRCLM      = 16_408, {value}
      JPI ASTLM      = 16_409, {value}
      JPI PAGEFLTS   = 16_40A, {value}
      JPI DIRIO      = 16_40B, {value}
      JPI BUFIO      = 16_40C, {value}
      JPI CPULIM     = 16_40D, {quadword value}
      JPI PGFLQUOTA  = 16_40E, {value}
      JPI FILLM      = 16_40F, {value}
      JPI TQLM       = 16_410, {value}
      JPI WSSIZE     = 16_411, {value}
      JPI AUTHPRIV   = 16_412, {quadword value}
      JPI IMAGPRIV   = 16_413, {quadword value}
      JPI PAGFILCNT  = 16_414, {value}
      JPI FREPTECNT  = 16_415, {value}
      JPI WSEXTENT   = 16_416, {value}
      JPI WSAUTHEXT  = 16_417, {value}
      JPI AUTHPRI    = 16_418, {quadword value}
      JPI PAGFILLOC  = 16_419, {value}
      JPI IMAGECOUNT = 16_41A, {value}
      JPI LASTPHD    = 16_41B
