!
! >> IMP equivalent for the $IODEF macro <<
!
! Symbolic values for I/O function codes
!
! Correct as of VAX/VMS version 3.1
!

!
! >> Function Codes <<
!
%const %integer -
   IO M FCODE      = 16_3F  {function code field, rest modifiers}

%const %integer -
   IO NOP          = 16_00,
   IO LOADMCODE    = 16_01,
   IO UNLOAD       = 16_01,
   IO STARTMPROC   = 16_02,
   IO SEEK         = 16_02,
   IO SPACEFILE    = 16_02,
   IO STOP         = 16_03,
   IO RECAL        = 16_03,
   IO INITIALIZE   = 16_04,
   IO DRVCLR       = 16_04,
   IO RELEASE      = 16_05,
   IO SETCLOCKP    = 16_05,
   IO OFFSET       = 16_06,
   IO ERASETAPE    = 16_06,
   IO STARTDATAP   = 16_06,
   IO QSTOP        = 16_07,
   IO RETCENTER    = 16_07,
   IO PACKACK      = 16_08,
   IO SEARCH       = 16_09,
   IO SPACERECORD  = 16_09,
   IO WRITECHECK   = 16_0A,
   IO WRITEPBLK    = 16_0B,
   IO READPBLK     = 16_0C,
   IO RDSTATS      = 16_0D,
   IO WRITEHEAD    = 16_0D,
   IO READHEAD     = 16_0E,
   IO WRITETRACKD  = 16_0F,
   IO READTRACKD   = 16_10,
   IO AVAILABLE    = 16_11,
   IO DSE          = 16_15,
   IO REREADN      = 16_16,
   IO REREADP      = 16_17
%const %integer %c
   IO WRITECHECKH  = 16_18,
   IO WRITERET     = 16_18,
   IO READPRESET   = 16_19,
   IO STARTSPNDL   = 16_19,
   IO SETCHAR      = 16_1A,
   IO SENSECHAR    = 16_1B,
   IO WRITEMARK    = 16_1C,
   IO WRTTMKR      = 16_1D,
   IO DIAGNOSE     = 16_1D,
   IO FORMAT       = 16_1E,
   IO CLEAN        = 16_1E,
   IO PHYSICAL     = 16_1F,
   IO WRITELBLK    = 16_20,
   IO READLBLK     = 16_21,
   IO REWINDOFF    = 16_22,
   IO SETMODE      = 16_23,
   IO REWIND       = 16_24,
   IO SKIPFILE     = 16_25,
   IO SKIPRECORD   = 16_26,
   IO SENSEMODE    = 16_27,
   IO WRITEOF      = 16_28,
   IO LOGICAL      = 16_2F,
   IO WRITEVBLK    = 16_30,
   IO READVBLK     = 16_31,
   IO ACCESS       = 16_32,
   IO CREATE       = 16_33,
   IO DEACCESS     = 16_34,
   IO DELETE       = 16_35,
   IO MODIFY       = 16_36,
   IO NETCONTROL   = 16_36,
   IO READPROMPT   = 16_37,
   IO FORCE        = 16_37,
   IO SETCLOCK     = 16_37
%const %integer %c
   IO ACPCONTROL   = 16_38,
   IO STARTDATA    = 16_38,
   IO MOUNT        = 16_39,
   IO TTYREADALL   = 16_3A,
   IO ENDRU1       = 16_3A,
   IO TTYREADPALL  = 16_3B,
   IO ENDRU2       = 16_3B,
   IO READINIT     = 16_3C,
   IO CONINTREAD   = 16_3C,
   IO CONINTWRITE  = 16_3D,
   IO VIRTUAL      = 16_3F

!
! >> Function modifiers <<
!
%const %integer %c
   IO M NOCTSWAIT  = 16_00000040,
   IO M SETEVF     = 16_00000040,
   IO M MAINT      = 16_00000040,
   IO M MORE       = 16_00000040,
   IO M NOMRSP     = 16_00000040,
   IO M REDIRECT   = 16_00000040,
   IO M FORCE      = 16_00000040,
   IO M NOECHO     = 16_00000040,
   IO M DELDATA    = 16_00000040,
   IO M INTERRUPT  = 16_00000040,
   IO M NOW        = 16_00000040,
   IO M WORD       = 16_00000040,
   IO M REVERSE    = 16_00000040,
   IO M CANCTRLO   = 16_00000040,
   IO M ACCESS     = 16_00000040,
   IO M COMMOD     = 16_00000040,
   IO M BINARY     = 16_00000040,
   IO M TYPEAHDCNT = 16_00000040,
   IO M STARTUP    = 16_00000040,
   IO M RD MEM     = 16_00000040

%const %integer -
   IO M MOVETRACKD = 16_00000080,
   IO M READATTN   = 16_00000080,
   IO M CREATE     = 16_00000080,
   IO M ENABLMBX   = 16_00000080,
   IO M SHUTDOWN   = 16_00000080,
   IO M TIMED      = 16_00000080,
   IO M NOWAIT     = 16_00000080,
   IO M CTRLYAST   = 16_00000080,
   IO M PACKED     = 16_00000080,
   IO M SLAVLOOP   = 16_00000080,
   IO M CTRLENTRY  = 16_00000080,
   IO M ACCEPT     = 16_00000080,
   IO M RD MODEM   = 16_00000080,
   IO M QUALIFIED  = 16_00000080,
   IO M LOOP       = 16_00000080

%const %integer -
   IO M CTRLCAST   = 16_00000100,
   IO M ABORT      = 16_00000100,
   IO M INTSKIP    = 16_00000100,
   IO M DELETE     = 16_00000100,
   IO M NOFORMAT   = 16_00000100,
   IO M CVTLOW     = 16_00000100,
   IO M DIAGNOSTIC = 16_00000100,
   IO M WRTATTN    = 16_00000100,
   IO M ATTNAST    = 16_00000100,
   IO M SETCUADR   = 16_00000100,
   IO M NODSRWAIT  = 16_00000100,
   IO M RD COUNT   = 16_00000100,
   IO M UNLOOP     = 16_00000100,
   IO M MULTIPLE   = 16_00000100

%const %integer -
   IO M SKPSECINH  = 16_00000200,
   IO M OPPOSITE   = 16_00000200,
   IO M SETBSIZE   = 16_00000200,
   IO M SETFNCT    = 16_00000200,
   IO M HANGUP     = 16_00000200,
   IO M NOFILTR    = 16_00000200,
   IO M SYNCH      = 16_00000200,
   IO M CTRL       = 16_00000200,
   IO M SETPROT    = 16_00000200,
   IO M MAINTLOOP  = 16_00000200,
   IO M LINE OFF   = 16_00000200,
   IO M MOUNT      = 16_00000200

%const %integer -
   IO M LASTBLOCK  = 16_00000400,
   IO M CLR COUNT  = 16_00000400,
   IO M OUTBAND    = 16_00000400,
   IO M SET MODEM  = 16_00000400,
   IO M DATAPATH   = 16_00000400,
   IO M SETPOOLSZ  = 16_00000400,
   IO M DSABLMBX   = 16_00000400,
   IO M DMOUNT     = 16_00000400,
   IO M CECYL      = 16_00000400,
   IO M SWAP       = 16_00000400

%const %integer -
   IO M ENABLE ALT = 16_00000800,
   IO M INHERLOG   = 16_00000800,
   IO M PURGE      = 16_00000800,
   IO M RESET      = 16_00000800,
   IO M INCLUDE    = 16_00000800,
   IO M LINE ON    = 16_00000800,
   IO M SETENQCNT  = 16_00000800

%const %integer -
   IO M INHSEEK    = 16_00001000,
   IO M INHEXTGAP  = 16_00001000,
   IO M CYCLE      = 16_00001000,
   IO M CLEAR      = 16_00001000,
   IO M DSABL ALT  = 16_00001000,
   IO M LOOP EXT   = 16_00001000,
   IO M INTCLOCK   = 16_00001000,
   IO M TRMNOECHO  = 16_00001000

%const %integer -
   IO M LPBEXT     = 16_00002000,
   IO M REFRESH    = 16_00002000,
   IO M DATACHECK  = 16_00004000,
   IO M LPBINT     = 16_00004000,
   IO M ESCAPE     = 16_00004000,
   IO M EXTEND     = 16_00008000,
   IO M READCSR    = 16_00008000,
   IO M INHRETRY   = 16_00008000

%end %of %file
