%record %format Lims Fm ( %integer Start,
                        ( %integer Limit %or %integer End %or %integer Finish ))

%system %integer %function %spec ADJSTK ( %integer Acmode, Adjust,
                                          %integer %name Newadr )

%system %integer %function %spec ADJWSL ( %integer Pagcnt,
                                          %integer %name Wsetlm )

%system %integer %function %spec CNTREG ( %integer Pagcnt,
                                          %record(Lims Fm) %name Retadr,
                                          %integer Acmode, Region )

%system %integer %function %spec EXPREG ( %integer Pagcnt,
                                          %record(Lims Fm) %name Retadr,
                                          %integer Acmode, Region )

%system %integer %function %spec CRETVA ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode )

%system %integer %function %spec DELTVA ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode )

%system %integer %function %spec LCKPAG ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode )

%system %integer %function %spec LKWSET ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode )

%system %integer %function %spec PURGWS ( %record(Lims Fm) %name Inadr )

%system %integer %function %spec SETPRT ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode, Prot,
                                          %byte %name PrvPrt )

%system %integer %function %spec SETSTK ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode )

%system %integer %function %spec UPDSEC ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode, Updflg, Efn,
                                          %record(*) %name IOSB, AST,
                                          %integer ASTPRM )

%system %integer %function %spec ULKPAG ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode )

%system %integer %function %spec ULWSET ( %record(Lims Fm) %name Inadr, Retadr,
                                          %integer Acmode )

