! format of condition values
%const %integer STS Control  = 16_F000 0000,  STS Inhibit  = 16_1000 0000
%const %integer STS Fac  No  = 16_0FFF 0000,  STS Cust Def = 16_0800 0000
%const %integer STS Cond Id  = 16_0FFF FFF8
%const %integer STS Msg  No  = 16_0000 FFF8,  STS Fac Sp   = 16_0000 8000
%const %integer STS Severity = 16_0000 0007,  STS Warning  = 16_0000 0000,
                                              STS Success  = 16_0000 0001,
                                              STS Error    = 16_0000 0002,
                                              STS Inf      = 16_0000 0003,
                                              STS Severe   = 16_0000 0004
%end %of %file
