%recordformat io status fm(%shortinteger Status, Count,
                           %integer Info)
%externalrecord(io status fm)%spec MT Status

%externalroutinespec Print Error(%integer Code)
%externalintegerfnspec Load MT(%string(63) Drive)
%externalroutinespec Rewind MT(%integer  Chan)
%externalroutinespec Unload MT(%integer Chan)
%externalroutinespec Read MT(%integer Chan, Buffer, Bytes)
%externalroutinespec Write MT(%integer Chan, Buffer, Bytes)
%externalroutinespec Tape mark MT(%integer Chan)

%endoffile
