%record %format Priv ( %integer A, B )

%record %format PHD Fm ( %c
   %record(Priv) PRIVMSK,
   %short   WSLIST, WSAUTH,
   %short   WSLOCK, WSDYN,
   %short   WSNEXT, WSLAST,
   %integer REFERFLT,
   %short   WSQUOTA, DFWSCNT,
   %byte    Bfill1, Bfill2, Bfill3, PAGFIL,
   %integer PSTBASOFF,
   %short   PSTLAST, PSTFREE,
   %integer FREP0VA, FREPTECNT,
   %integer FREP1VA,
   %byte    DFPFC, PGTBPFC,
   %short   FLAGS,
   %integer CPUTIM,
   %short   QUANT, PRCLIM,
   %short   ASTLIM, PHVINDEX,
   %short   BAK, PSTBASMAX,
   %integer PAGEFLTS, PGFLTIO, DIOCNT, BIOCNT, CPULIM,
   %byte    CPUMODE, Bfill4, Bfill5, Bfill6,
   %integer PTWSLELCK, PTWSLEVAL,
   %short   PTCNTLCK, PTCNTVAL, PTCNTACT, PTCNTMAX,
   %short   WSFLUID, EXTDYNWS,
{HARDWARE PCB STARTS HERE} %c
   %integer KSP,ESP,SSP,USP,
   %integer R0, R1, R2, R3, R4, R5, R6, R7,
   %integer R8, R9, R10, R11, R12, R13, PC, PSL,
   %integer P0BR,
 ( %integer P0LRASTL %or %byte Bfill7, Bfill8, Bfill9, ASTLVL ),
   %integer P1BR,
   %integer P1LR,
{END OF HARDWARE PCB} %c
   %short   EMPTPG, RESPGCNT,
   %short   REQPGCNT, CWSLX,
   %record(Priv) AUTHPRIV, IMAGPRIV,
   %integer Spare1,
   %integer RESLSTH,
   %integer IMGCNT,
   %integer PFLTRATE,
   %integer PFLREF,
   %integer TIMREF,
   %integer %array Spare2 ( 1: 31 ) )

%end %of %file
