!
! Mailbox services
!
%external %integer %function %spec CREMBX %alias "IMP_CREMBX" ( %c
          %integer Prmflg, %integer %name Chan,
          %integer Maxmsg, Bufquo, Promsk, Acmode,
          %string(63) Lognam )

%external %integer %function %spec DELMBX %alias "IMP_DELMBX" ( %c
          %integer Chan )
