!
! IMP version of $DVIDEF macro
!
%const %integer %c
      DVI DEVCHAR         = 2,
      DVI DEVCLASS        = 4,
      DVI DEVTYPE         = 6,
      DVI DEVBUFSIZ       = 8,
      DVI DEVDEPEND       = 10,
      DVI UNIT            = 12,
      DVI PID             = 14,
      DVI OWNUIC          = 16,
      DVI VPROT           = 18,
      DVI ERRCNT          = 20,
      DVI OPCNT           = 22,
      DVI RECSIZ          = 24,
      DVI MAXBLOCK        = 26,
      DVI DEVDEPEND2      = 28,
      DVI REFCNT          = 30,
      DVI DEVNAM          = 32,
      DVI VOLNAM          = 34,
      DVI SECTORS         = 36,
      DVI TRACKS          = 38,
      DVI CYLINDERS       = 40,
      DVI FREEBLOCKS      = 42,
      DVI LOGVOLNAM       = 44,
      DVI VOLNUMBER       = 46,
      DVI VOLCOUNT        = 48,
      DVI ROOTDEVNAM      = 50,
      DVI NEXTDEVNAM      = 52,
      DVI TRANSCNT        = 54,
      DVI MOUNTCNT        = 56,
      DVI CLUSTER         = 58,
      DVI MAXFILES        = 60,
      DVI SERIALNUM       = 62,
      DVI ACPPID          = 64,
      DVI ACPTYPE         = 66

%const %integer %c
      DVI C SECONDARY     = 1,
      DVI C ACP F11V1     = 1,
      DVI C ACP F11V2     = 2,
      DVI C ACP MTA       = 3,
      DVI C ACP NET       = 4,
      DVI C ACP REM       = 5,
      DVI C ACP JNL       = 6
