%record %format Num Tim Fm ( ( %short Year, Month, Day, Hour,
                               %short Minute, Second, Hundredth ) %or
                             %short %array Word ( 1: 7 ) )

%record %format Bin Tim Fm ( %integer Long1, Long2 )

%external %integer %function %spec ASCTIM %alias "IMP_ASCTIM" %c
                           ( %integer TIMLEN, %string(*) %name TIMBUF,
                             %record(Bin Tim Fm) %name TIMADR,
                             %integer CVTFLG )
                                             
%external %integer %function %spec BINTIM %alias "IMP_BINTIM" ( %c
                             %string(255) TIMBUF,
                             %record(Bin Tim Fm) %name TIMADR )

%system %integer %function %spec CANTIM ( %integer REQIDT, ACMODE )

%system %integer %function %spec GETTIM ( %record(Bin Tim Fm) %name TIMADR )

%system %integer %function %spec NUMTIM ( %record(Num Tim Fm) %name TIMBUF,
                                          %record(Bin Tim Fm) %name TIMADR )

%external %integer %function %spec SCHDWK %alias "IMP_SCHDWK" ( -
                             %integer PID, %string(15) PRCNAM,
                             %record(Bin Tim Fm) %name Daytim, Reptim )

%system %integer %function %spec SETIME ( %record(Bin Tim Fm) %name TIMADR )

%system %integer %function %spec SETIMR ( %integer Efn,
                                          %record(Bin Tim Fm) %name DAYTIM,
                                          %record(*) %name ASTADR,
                                          %integer REQIDT )

%external %routine %spec Wait %alias "IMP_WAIT" ( %integer Msecs )
%external %string(9) %function %spec Today %alias "IMP_TODAY"

%end %of %file
